bayespy.nodes.GaussianMarkovChain.lower_bound_contribution
==========================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianMarkovChain.lower_bound_contribution